/*
 * @Author: weisheng
 * @Date: 2023-04-17 12:51:22
 * @LastEditTime: 2023-04-20 15:01:53
 * @LastEditors: weisheng
 * @Description:
 * @FilePath: \uniapp-vue3-fant-ts\src\api\DemoApi.ts
 * 记得注释
 */
import http from '@/http/HttpClient';
import BaseResponse from '@/model/BaseResponse';
import Chanel from '@/model/Chanel';
import UserInfo from '@/model/UserInfo';
import getTime from '@/utils/getTime';
// 这里将API方法统一管理
export default class DemoApi {
  // 获取项目名称
  static getProjectNameList(data): Promise<BaseResponse<UserInfo>> {
    return http
      .server(data)
      .get(
        'bi-api/report/dataapi/project_info' +
          `?${Object.keys(getTime)
            .map((key) => {
              return `${key}=${getTime[key]}`;
            })
            .join('&')}`
      )
      .then((res) => {
        return res.data;
      });
  }
  // 获取油品型号
  // https://miniapp.zhangmushiye.com/bi-api/report/dataapi/project_oil_info
  static getOilTypeList(data): Promise<BaseResponse<UserInfo>> {
    let allData = {
      ...getTime,
      ...data,
    };
    return http
      .server()
      .get(
        'bi-api/report/dataapi/project_oil_info' +
          `?${Object.keys({ ...getTime, ...data })
            .map((key) => {
              return `${key}=${allData[key]}`;
            })
            .join('&')}`
      )
      .then((res) => {
        return res.data;
      });
  }
  //  获取客户列表 getCustomerList
  static getCustomerList(data): Promise<BaseResponse<UserInfo>> {
    let allData = {
      ...getTime,
      ...data,
    };
    return http
      .server()
      .get(
        'bi-api/report/dataapi/customerinfo_api' +
          `?${Object.keys(allData)
            .map((key) => {
              return `${key}=${allData[key]}`;
            })
            .join('&')}`
      )
      .then((res) => {
        return res.data;
      });
  }

  // https://miniapp.zhangmushiye.com/bi-api/report/dataapi/payment_api
  //开票公司
  static getInvoiceCompanyList(data): Promise<BaseResponse<UserInfo>> {
    let allData = {
      ...getTime,
      ...data,
    };
    return http
      .server()
      .get(
        'bi-api/report/dataapi/payment_api' +
          `?${Object.keys(allData)
            .map((key) => {
              return `${key}=${allData[key]}`;
            })
            .join('&')}`
      )
      .then((res) => {
        return res.data;
      });
  }
  // 获取单价 /bi-api/report/dataapi/odsbuy
  static getUnitPriceList(data): Promise<BaseResponse<UserInfo>> {
    return http
      .server()
      .get(
        'bi-api/report/dataapi/odsbuy' +
          `?${Object.keys(data)
            .map((key) => {
              return `${key}=${data[key]}`;
            })
            .join('&')}`
      )
      .then((res) => {
        return res.data;
      });
  }
  // 获取客户getKehuList
  // /bi-api/report/dataapi/customerinfo_api
  static getKehuList(data): Promise<BaseResponse<UserInfo>> {
    return http
      .server()
      .get(
        'bi-api/report/dataapi/customerinfo_api' +
          `?${Object.keys(data)
            .map((key) => {
              return `${key}=${data[key]}`;
            })
            .join('&')}`
      )
      .then((res) => {
        return res.data;
      });
  }
  // config 结算管理 接口
  static getConfig(data): Promise<BaseResponse<Chanel[]>> {
    return http
      .server(data)
      .get('visual-api/paas/visualdev/OnlineDev/' + data + '/Config')
      .then((res) => {
        return res.data;
      });
  }
  // 项目列表
  static getFormDataList(data): Promise<BaseResponse<Chanel[]>> {
    return http
      .server()
      .post('bi-api/cube/browser/' + data.dbLinkId, data)
      .then((res) => {
        return res.data;
      });
  }
  // 获取表单Url
  static getSelectOptionsUrl(id): Promise<BaseResponse<Chanel[]>> {
    return http
      .server()
      .get('bi-api/report/dataapi/detail?id=' + id)
      .then((res) => {
        return res.data;
      });
  }
  // 根据url拼接
  static getSelectOptionsUrlByParams(url): Promise<BaseResponse<Chanel[]>> {
    return http
      .server()
      .get(
        url +
          `?${Object.keys(getTime)
            .map((key) => {
              return `${key}=${getTime[key]}`;
            })
            .join('&')}`
      )
      .then((res) => {
        return res.data;
      });
  }
  // 编辑
  // https://miniapp.zhangmushiye.com/visual-api/paas/visualdev/OnlineDev/v2
  static getEditData(data): Promise<BaseResponse<Chanel[]>> {
    return http
      .server()
      .put(
        'visual-api/paas/visualdev/OnlineDev/v2/' + data.formKey + data.id,
        data.data
      )
      .then((res) => {
        return res.data;
      });
  }
  static getAddData(data): Promise<BaseResponse<Chanel[]>> {
    return http
      .server()
      .post(
        'visual-api/paas/visualdev/OnlineDev/v2/' + data.formKey + data.id,
        data.data
      )
      .then((res) => {
        return res.data;
      });
  }
  static deleteListData(data): Promise<BaseResponse<Chanel[]>> {
    return http
      .server()
      .delete(
        'visual-api/paas/visualdev/OnlineDev/' +
          data.formKey +
          data.id +
          '?dataJson=' +
          data.jsonData
      )
      .then((res) => {
        return res.data;
      });
  }
}
